@@ -31,6 +31,7 @@ import yaml
 import socket
 import json
 import time
+import re
 from typing import Dict, Any, Optional, List
 from pathlib import Path
 from datetime import datetime
@@ -40,8 +41,8 @@ logger = logging.getLogger(__name__)
 class EventSocketManager:
     """Manages Unix socket connection for real-time event emission"""
 
-    def __init__(self, socket_path: str = '/tmp/statemachine-events.sock'):
-        self.socket_path = socket_path
+    def __init__(self, socket_path: str = None):
+        self.socket_path = socket_path or '/tmp/statemachine-events.sock'
         self.sock: Optional[socket.socket] = None
         self.logger = logging.getLogger(__name__)
         self._connect()
@@ -88,17 +89,20 @@ class StateMachineEngine:
     
     """
     
-    def __init__(self, machine_name: str = None, actions_root: str = None):
+    def __init__(self, machine_name: str = None, actions_root: str = None, event_socket_path: str = None, control_socket_prefix: str = None):
         self.config = None
         self.current_state = None
         self.context = {}
         self.actions = {}
         self.machine_name = machine_name
+        self.config_name = None  # Configuration type for diagram mapping
         self.actions_root = actions_root  # Custom actions directory
-        self.event_socket = EventSocketManager()  # NEW: Unix socket for real-time events
+        self.control_socket_prefix = control_socket_prefix or '/tmp/statemachine-control'  # Control socket prefix
+        self.event_socket = EventSocketManager(socket_path=event_socket_path)  # NEW: Unix socket for real-time events
         self.control_socket: Optional[socket.socket] = None  # Control socket for receiving events
         self.is_running = True
         self.propagation_count = 0  # Track frequency of job context propagation
+        self.timeout_tasks: Dict[str, asyncio.Task] = {}  # Track active timeout tasks per state
         
     async def load_config(self, yaml_path: str) -> None:
         """Load state machine configuration from YAML file"""
@@ -108,6 +112,11 @@ class StateMachineEngine:
             
         with open(config_path, 'r') as f:
             self.config = yaml.safe_load(f)
+        
+        # Extract config name from file path for diagram mapping
+        # This MUST match the diagram directory name (e.g., "controller.yaml" -> "controller")
+        # The YAML 'name' field is just a human-readable label, not the config identifier
+        self.config_name = config_path.stem  # e.g., "patient-records.yaml" -> "patient-records"
             
         # Set initial state
         self.current_state = self.config.get('initial_state', 'waiting')
@@ -133,7 +142,7 @@ class StateMachineEngine:
     
     def _create_control_socket(self) -> None:
         """Create Unix socket for receiving control events"""
-        socket_path = f'/tmp/statemachine-control-{self.machine_name}.sock'
+        socket_path = f'{self.control_socket_prefix}-{self.machine_name}.sock'
         
         try:
             # Remove stale socket file if it exists
@@ -225,6 +234,9 @@ class StateMachineEngine:
         
         logger.info(f"[{self.machine_name}] Starting state machine execution from state: {self.current_state}")
         
+        # Start timeout tasks for initial state (if any)
+        self._start_timeout_tasks(self.current_state)
+        
         # Start with initial event
         await self.process_event("start", self.context)
         
@@ -234,7 +246,7 @@ class StateMachineEngine:
             await self._check_control_socket()
             
             # Check if we've reached a terminal state
-            if self.current_state == "stopped":
+            if self.current_state in ["stopped", "shutdown", "completed"]:
                 logger.info(f"[{self.machine_name}] State machine reached terminal state: {self.current_state}")
                 break
                 
@@ -256,6 +268,9 @@ class StateMachineEngine:
         
         # Cleanup on exit
         self._cleanup_sockets()
+        
+        # Remove machine from database when terminating
+        self._delete_machine_state()
     
     async def process_event(self, event: str, context: Dict[str, Any] = None) -> bool:
         """Process an event and potentially transition to a new state"""
@@ -269,7 +284,12 @@ class StateMachineEngine:
         
         # Find valid transition
         new_state = await self._find_transition(self.current_state, event)
-        if new_state:            
+        if new_state:
+            # Cancel any active timeout tasks when transitioning to a new state
+            # (unless the event itself is a timeout event)
+            if not event.startswith('timeout('):
+                self._cancel_timeout_tasks()
+            
             # Only log state transitions for important events, skip idle cycles and self-loops
             is_self_loop = (self.current_state == new_state)
             is_idle_event = event in ['wake_up', 'no_events', 'no_jobs']
@@ -342,6 +362,9 @@ class StateMachineEngine:
             should_emit_to_ui = not (is_self_loop and is_idle_event)
             await self._log_state_change(previous_state, new_state, event, emit_to_ui=should_emit_to_ui)
             
+            # Start timeout tasks for the new state (if any timeout transitions exist)
+            self._start_timeout_tasks(new_state)
+            
             return True
         else:
             # Only log missing transitions for non-idle events
@@ -371,17 +394,64 @@ class StateMachineEngine:
             try:
                 import os
                 with job_model.db._get_connection() as conn:
+                    # Check if this is a new machine (for machine_registered event)
+                    existing = conn.execute(
+                        "SELECT COUNT(*) FROM machine_state WHERE machine_name = ?",
+                        (self.machine_name,)
+                    ).fetchone()[0]
+                    
+                    is_new = (existing == 0)
+                    
                     conn.execute("""
-                        INSERT INTO machine_state (machine_name, current_state, last_activity, pid, metadata)
-                        VALUES (?, ?, ?, ?, ?)
+                        INSERT INTO machine_state (machine_name, current_state, last_activity, pid, metadata, config_type)
+                        VALUES (?, ?, ?, ?, ?, ?)
                         ON CONFLICT(machine_name) DO UPDATE SET
                             current_state = excluded.current_state,
                             last_activity = excluded.last_activity,
-                            pid = excluded.pid
-                    """, (self.machine_name, current_state, time.time(), os.getpid(), None))
+                            pid = excluded.pid,
+                            config_type = excluded.config_type
+                    """, (self.machine_name, current_state, time.time(), os.getpid(), None, self.config_name))
                     conn.commit()
+                    
+                # Emit machine_registered event for new machines
+                if is_new:
+                    event_payload = {
+                        'machine_name': self.machine_name,
+                        'config_type': self.config_name,
+                        'current_state': current_state,
+                        'timestamp': time.time()
+                    }
+                    logger.info(f"[{self.machine_name}] 📤 Emitting machine_registered: config_type={self.config_name}")
+                    self._emit_realtime_event('machine_registered', event_payload)
+                    logger.info(f"[{self.machine_name}] ✨ Machine registered: {self.config_name}")
             except Exception as e:
-                logger.debug(f"[{self.machine_name}] Failed to update machine_state: {e}")
+                logger.warning(f"[{self.machine_name}] Failed to update machine_state: {e}")
+        else:
+            logger.warning(f"[{self.machine_name}] Cannot update machine_state: job_model={job_model is not None}, machine_name={self.machine_name}")
+    
+    def _delete_machine_state(self):
+        """Delete machine from machine_state table when terminating"""
+        job_model = self.context.get('job_model')
+        if job_model and hasattr(job_model, 'db') and self.machine_name:
+            try:
+                with job_model.db._get_connection() as conn:
+                    conn.execute("""
+                        DELETE FROM machine_state WHERE machine_name = ?
+                    """, (self.machine_name,))
+                    conn.commit()
+                logger.info(f"[{self.machine_name}] Removed from machine_state table")
+                
+                # Emit machine_terminated event
+                self._emit_realtime_event('machine_terminated', {
+                    'machine_name': self.machine_name,
+                    'config_type': self.config_name,
+                    'timestamp': time.time()
+                })
+                logger.info(f"[{self.machine_name}] 👋 Machine terminated: {self.config_name}")
+            except Exception as e:
+                logger.warning(f"[{self.machine_name}] Failed to delete machine_state: {e}")
+        else:
+            logger.debug(f"[{self.machine_name}] No machine_state to delete")
     
     def _emit_realtime_event(self, event_type: str, payload: dict):
         """Emit event via Unix socket with database fallback"""
@@ -452,6 +522,76 @@ class StateMachineEngine:
                 
         return None
     
+    def _get_timeout_transitions(self, state: str) -> List[Dict[str, Any]]:
+        """Get all timeout transitions for a given state
+        
+        Returns list of dicts with keys: 'to_state', 'duration', 'event_name'
+        """
+        timeout_pattern = re.compile(r'^timeout\((\d+(?:\.\d+)?)\)$')
+        transitions = self.config.get('transitions', [])
+        timeout_transitions = []
+        
+        for transition in transitions:
+            from_state = transition.get('from')
+            to_state = transition.get('to')
+            on_event = transition.get('event')
+            
+            # Check if this is a timeout event for current state
+            if from_state == state or from_state == '*':
+                match = timeout_pattern.match(on_event)
+                if match:
+                    duration = float(match.group(1))
+                    timeout_transitions.append({
+                        'to_state': to_state,
+                        'duration': duration,
+                        'event_name': on_event
+                    })
+        
+        return timeout_transitions
+    
+    async def _timeout_handler(self, state: str, event_name: str, duration: float) -> None:
+        """Handle timeout for a state - sleeps for duration then fires event"""
+        try:
+            await asyncio.sleep(duration)
+            # If we reach here, timeout wasn't cancelled - fire the timeout event
+            logger.info(f"[{self.machine_name}] ⏰ Timeout {event_name} fired after {duration}s in state '{state}'")
+            await self.process_event(event_name)
+        except asyncio.CancelledError:
+            # Timeout was cancelled (expected when leaving state or receiving other event)
+            logger.debug(f"[{self.machine_name}] Timeout {event_name} cancelled for state '{state}'")
+    
+    def _start_timeout_tasks(self, state: str) -> None:
+        """Start timeout tasks for a state"""
+        # Cancel any existing timeout tasks first
+        self._cancel_timeout_tasks()
+        
+        # Get timeout transitions for this state
+        timeout_transitions = self._get_timeout_transitions(state)
+        
+        if timeout_transitions:
+            for timeout_spec in timeout_transitions:
+                event_name = timeout_spec['event_name']
+                duration = timeout_spec['duration']
+                to_state = timeout_spec['to_state']
+                
+                # Create timeout task
+                task = asyncio.create_task(
+                    self._timeout_handler(state, event_name, duration)
+                )
+                self.timeout_tasks[event_name] = task
+                
+                logger.debug(
+                    f"[{self.machine_name}] ⏰ Started timeout {event_name} "
+                    f"({duration}s) for state '{state}' -> '{to_state}'"
+                )
+    
+    def _cancel_timeout_tasks(self) -> None:
+        """Cancel all active timeout tasks"""
+        for event_name, task in self.timeout_tasks.items():
+            if not task.done():
+                task.cancel()
+        self.timeout_tasks.clear()
+    
     def _propagate_job_context(self) -> None:
         """Propagate job data from current_job to main context for variable substitution"""
         current_job = self.context.get('current_job')
@@ -662,10 +802,13 @@ class StateMachineEngine:
             await self.process_event('error')
     
     def _cleanup_sockets(self) -> None:
-        """Clean up Unix sockets on shutdown"""
+        """Clean up Unix sockets and timeout tasks on shutdown"""
+        # Cancel any active timeout tasks
+        self._cancel_timeout_tasks()
+        
         if self.control_socket:
             try:
-                socket_path = f'/tmp/statemachine-control-{self.machine_name}.sock'
+                socket_path = f'{self.control_socket_prefix}-{self.machine_name}.sock'
                 self.control_socket.close()
                 
                 # Remove socket file
