@@ -9,13 +9,32 @@ export class WebSocketManager {
         this.maxReconnectDelay = 30000; // 30 seconds
         this.pingInterval = null;
         this.eventHandlers = eventHandlers;
+        this.websocketUrl = null;
     }
 
-    connect() {
+    async connect() {
         this.log('info', 'Connecting to WebSocket server...');
 
+        // Fetch configuration if not already available
+        if (!this.websocketUrl) {
+            try {
+                const response = await fetch('/api/config');
+                const config = await response.json();
+                this.websocketUrl = config.websocket_url;
+                this.log('info', `WebSocket URL: ${this.websocketUrl}`);
+            } catch (error) {
+                console.error('Failed to fetch WebSocket configuration:', error);
+                this.log('error', 'Failed to get WebSocket configuration');
+                // Fallback to default port 3002 or derive from UI port
+                const uiPort = window.location.port || '3001';
+                const fallbackWsPort = uiPort === '3001' ? '3002' : (parseInt(uiPort) + 1);
+                this.websocketUrl = `ws://localhost:${fallbackWsPort}/ws/events`;
+                this.log('warning', 'Using fallback WebSocket URL: ' + this.websocketUrl);
+            }
+        }
+
         try {
-            this.websocket = new WebSocket('ws://localhost:3002/ws/events');
+            this.websocket = new WebSocket(this.websocketUrl);
 
             this.websocket.onopen = () => {
                 this.isConnected = true;
@@ -27,7 +46,10 @@ export class WebSocketManager {
             this.websocket.onmessage = (event) => {
                 try {
                     const data = JSON.parse(event.data);
-                    console.debug('WebSocket message received:', data);
+                    // Log all events except ping for visibility
+                    if (data.type !== 'ping') {
+                        console.log(`[WebSocket] Received: ${data.type}`, data);
+                    }
                     this.handleEvent(data);
                 } catch (e) {
                     console.error('Failed to parse WebSocket message:', e, 'Raw data:', event.data);
@@ -105,8 +127,8 @@ export class WebSocketManager {
         this.reconnectAttempts++;
         this.log('info', `Reconnecting in ${delay/1000}s...`);
 
-        setTimeout(() => {
-            this.connect();
+        setTimeout(async () => {
+            await this.connect();
         }, delay);
     }
 
